==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/app/graphql/mutations/dependency_proxy/image_ttl_group_policy/update.rb <==
# frozen_string_literal: true

module Mutations
  module DependencyProxy
    module ImageTtlGroupPolicy
      class Update < Mutations::BaseMutation
        graphql_name 'UpdateDependencyProxyImageTtlGroupPolicy'

        include Mutations::ResolvesGroup

        description <<~DESC
          These settings can be adjusted by the group Owner or Maintainer.
          [Issue 370471](https://gitlab.com/gitlab-org/gitlab/-/issues/370471) proposes limiting
          this to Owners only to match the permissions level in the user interface.
        DESC

        authorize :admin_dependency_proxy

        argument :group_path,
                GraphQL::Types::ID,
                required: true,
                description: 'Group path for the group dependency proxy image TTL policy.'

        argument :enabled,
                GraphQL::Types::Boolean,
                required: false,
                description: copy_field_description(Types::DependencyProxy::ImageTtlGroupPolicyType, :enabled)

        argument :ttl,
                GraphQL::Types::Int,
                required: false,
                description: copy_field_description(Types::DependencyProxy::ImageTtlGroupPolicyType, :ttl)

        field :dependency_proxy_image_ttl_policy,
              Types::DependencyProxy::ImageTtlGroupPolicyType,
              null: true,
              description: 'Group image TTL policy after mutation.'

        def resolve(group_path:, **args)
          group = authorized_find!(group_path: group_path)

          result = ::DependencyProxy::ImageTtlGroupPolicies::UpdateService
            .new(container: group, current_user: current_user, params: args)
            .execute

          {
            dependency_proxy_image_ttl_policy: result.payload[:dependency_proxy_image_ttl_policy],
            errors: result.errors
          }
        end

        private

        def find_object(group_path:)
          resolve_group(full_path: group_path)
        end
      end
    end
  end
end

==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/app/graphql/mutations/dependency_proxy/image_ttl_group_policy/update.rb <==
# frozen_string_literal: true

module Mutations
  module DependencyProxy
    module ImageTtlGroupPolicy
      class Update < Mutations::BaseMutation
        graphql_name 'UpdateDependencyProxyImageTtlGroupPolicy'

        include Mutations::ResolvesGroup

        description 'These settings can be adjusted only by the group Owner.'

        authorize :admin_dependency_proxy

        argument :group_path,
                GraphQL::Types::ID,
                required: true,
                description: 'Group path for the group dependency proxy image TTL policy.'

        argument :enabled,
                GraphQL::Types::Boolean,
                required: false,
                description: copy_field_description(Types::DependencyProxy::ImageTtlGroupPolicyType, :enabled)

        argument :ttl,
                GraphQL::Types::Int,
                required: false,
                description: copy_field_description(Types::DependencyProxy::ImageTtlGroupPolicyType, :ttl)

        field :dependency_proxy_image_ttl_policy,
              Types::DependencyProxy::ImageTtlGroupPolicyType,
              null: true,
              description: 'Group image TTL policy after mutation.'

        def resolve(group_path:, **args)
          group = authorized_find!(group_path: group_path)

          result = ::DependencyProxy::ImageTtlGroupPolicies::UpdateService
            .new(container: group, current_user: current_user, params: args)
            .execute

          {
            dependency_proxy_image_ttl_policy: result.payload[:dependency_proxy_image_ttl_policy],
            errors: result.errors
          }
        end

        private

        def find_object(group_path:)
          resolve_group(full_path: group_path)
        end
      end
    end
  end
end
